<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * Blog block
 *
 * @since 1.0.0
 */

class Preferred_Magazine_Featured_News extends Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve oEmbed widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */

    public function get_name() {
        return 'Featured News';
    }

    /**
     * Get widget title.
     *
     * Retrieve oEmbed widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */

    public function get_title() {
        return __( 'Featured News', 'preferred-magazine' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve oEmbed widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */

    public function get_icon() {
        return 'fa fa-file-text';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the oEmbed widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */

    public function get_categories() {
        return [ 'preferred_magazine' ];
    }

    /**
     * Register oEmbed widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */

    protected function _register_controls() {

        $this->start_controls_section(
            'featured_news_section',
            [
                'label' => __( 'Setting', 'preferred-magazine' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $category_slider_array = $this->prepare_cats_for_select();

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Title', 'preferred-magazine' ),
                'placeholder' => __( 'Title', 'preferred-magazine' ),
            ]
        );

        $this->add_control(
            'hr2',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );

        $this->add_control(
            'category_style',
            [
                'label' => __( 'Select Layout Style', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1' => __( 'Layout 1', 'preferred-magazine' ),
                    '2' => __( 'Layout 2 ( slideshow )', 'preferred-magazine' )
                ],
                'default' => '1',
            ]
        );
        $this->add_control(
            'categories',
            [
                'label' => __( 'Select your categories', 'preferred-magazine' ),
                'type' => Controls_Manager::SELECT2,
                'dynamic' => [
                    'active' => true,
                ],
                'options' => $category_slider_array,
                'multiple' => false
            ]
        );
        $this->add_control(
            'limit',
            [
                'label' => __( 'Post Limit', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 25,
                'step' => 1,
                'default' => 2,
            ]
        );
        $this->add_control(
            'hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        $this->add_control(
            'hide_meta',
            [
                'label' => __( 'Hide Meta?', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'preferred-magazine' ),
                'label_off' => __( 'Hide', 'preferred-magazine' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'hide_category',
            [
                'label' => __( 'Hide Category?', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'preferred-magazine' ),
                'label_off' => __( 'Hide', 'preferred-magazine' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]

        );

        $this->add_control(
            'hide_read_time',
            [
                'label' => __( 'Hide Reading Time?', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'preferred-magazine' ),
                'label_off' => __( 'Hide', 'preferred-magazine' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render oEmbed widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */

    protected function render() {
        $settings = $this->get_settings_for_display();
        $category_slider = is_array( $settings['categories'] ) ? implode( ',', $settings['categories'] ) : $settings['categories'];
        $query = new \WP_Query( array(
            'posts_per_page'      => $settings['limit'],
            'no_found_rows'       => true,
            'post_stairis'         => 'publish',
            'ignore_sticky_posts' => true,
            'cat' 			      => $category_slider
        ) );
        $layout = $settings['category_style'];
        ?>
        <div class="pm-featured-news-post pm-featured-news-<?php echo esc_attr( $layout ); ?>">
            <?php if( $settings['title'] != '' ) : ?>
                <div class="featured-news-title">
                    <h2 class="mb-0"><?php echo esc_html( $settings['title'] ); ?></h2>
                </div>
            <?php endif; ?>
            <div class="row">
                <?php

                if ( $query->have_posts() ) :
                    while ( $query->have_posts() ) : $query->the_post();
                        ?>
                        <div class="col-md-6 col-sm-6 col-12 mt-30 slider-item">
                            <div class="post-item<?php echo ( has_post_thumbnail() ) ? '  has-block-thumb' : ''; ?> position-relative">
                                <?php if ( has_post_thumbnail() ) : ?>
                                    <a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php the_post_thumbnail( 'preferred-magazine-md-thumb' ); ?></a>
                                <?php endif; ?>
                                <div class="block-contents">
                                    <?php if ( 'yes' === $settings['hide_category'] ) {  ?>
                                        <div class="block-cats">
                                            <?php preferred_magazine_cat_bg(); ?>
                                        </div>
                                    <?php }  ?>
                                    <h2>
                                        <a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php echo esc_html( get_the_title() ); ?></a>
                                    </h2>
                                    <div class="meta-data">
                                        <?php if ( 'yes' === $settings['hide_read_time'] ) {
                                            preferred_magazine_readingWP();
                                        }
                                        if ( 'yes' === $settings['hide_meta'] ) {
                                            ?>
                                            <span>
                                                <i class="ion-ios-time-outline"></i> <?php echo get_the_date(); ?>
                                            </span>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div>

                    <?php
                    endwhile;
                    wp_reset_postdata();
                endif; ?>
            </div>
        </div>
        <?php
    }
    /**
     * Prepare posts to be used in the SELECT2 field
     */

    private function prepare_cats_for_select() {
        $categories = get_categories();
        $options = ['' => ''];
        foreach ( $categories as $cat ) {
            $options[$cat->term_id] = $cat->name;
        }
        return $options;
    }
}
Plugin::instance()->widgets_manager->register_widget_type( new Preferred_Magazine_Featured_News() );