<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * Blog block
 *
 * @since 1.0.0
 */

class Preferred_Magazine_Trading_Posts extends Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve oEmbed widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */

    public function get_name() {
        return 'Trading Post';
    }

    /**
     * Get widget title.
     *
     * Retrieve oEmbed widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */

    public function get_title() {
        return __( 'Trading Post', 'preferred-magazine' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve oEmbed widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */

    public function get_icon() {
        return 'fa fa-transgender';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the oEmbed widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */

    public function get_categories() {
        return [ 'preferred_magazine' ];
    }

    /**
     * Register oEmbed widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */

    protected function _register_controls() {

        $this->start_controls_section(
            'trading_post_section',
            [
                'label' => __( 'Setting', 'preferred-magazine' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
        $category_slider_array = $this->prepare_cats_for_select();

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Trading Posts', 'preferred-magazine' ),
                'placeholder' => __( 'Trading Posts', 'preferred-magazine' ),
            ]
        );

        $this->add_control(
            'categories',
            [
                'label' => __( 'Select your categories', 'preferred-magazine' ),
                'type' => Controls_Manager::SELECT2,
                'dynamic' => [
                    'active' => true,
                ],
                'options' => $category_slider_array,
                'multiple' => true
            ]
        );

        $this->add_control(
            'limit',
            [
                'label' => __( 'Post Limit', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 25,
                'step' => 1,
                'default' => 4,
            ]
        );
        $this->add_control(
            'hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );

        $this->add_control(
            'hide_meta',
            [
                'label' => __( 'Hide Meta?', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'preferred-magazine' ),
                'label_off' => __( 'Hide', 'preferred-magazine' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'hide_read_time',
            [
                'label' => __( 'Hide Reading Time?', 'preferred-magazine' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'preferred-magazine' ),
                'label_off' => __( 'Hide', 'preferred-magazine' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render oEmbed widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */

    protected function render() {
        $settings = $this->get_settings_for_display();
        $category_slider = is_array( $settings['categories'] ) ? implode( ',', $settings['categories'] ) : $settings['categories'];

        $query = new \WP_Query( array(
            'posts_per_page'      => $settings['limit'],
            'no_found_rows'       => true,
            'post_stairis'         => 'publish',
            'ignore_sticky_posts' => true,
            'cat' 			      => $category_slider
        ) ); ?>

        <div class="trading-post">

            <div class="row">

                <?php

                if ( $query->have_posts() ) :
                    if( $settings['title'] != '' ) : ?>
                        <div class="col-12 post-title">
                            <h2 class="mb-0"><?php echo esc_html( $settings['title'] ); ?></h2>
                        </div>

                    <?php endif;

                    ?><div class="trading-post-slider"><?php
                    while ( $query->have_posts() ) : $query->the_post(); ?>
                        <div class="col-12 pt-15">
                            <div class="post-item row">
                                <?php if ( has_post_thumbnail() ) : ?>
                                    <div class="cat-over-img position-relative col-md-4 col-12 mb-2 mb-lg-0 mb-md-0">
                                        <a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php the_post_thumbnail( 'preferred-magazine-sm-thumb' ); ?></a>

                                    </div>

                                <?php endif; ?>

                                <div class="block-contents col-md-8 col-12 align-self-end">
                                    <h5>
                                        <a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php echo esc_html( get_the_title() ); ?></a>
                                    </h5>

                                    <div class="meta-data mb-10">
                                        <?php if ( 'yes' === $settings['hide_read_time'] ) {
                                            preferred_magazine_readingWP();
                                        }
                                        if ( 'yes' === $settings['hide_meta'] ) {
                                            ?>
                                            <span>
                                                <i class="ion-ios-time-outline"></i> <?php echo get_the_date(); ?>
                                            </span>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div>

                    <?php
                    endwhile;
                    wp_reset_postdata();
                    ?></div><?php

                endif; ?>
            </div>
        </div>

        <?php
    }

    /**
     * Prepare posts to be used in the SELECT2 field
     */

    private function prepare_cats_for_select() {
        $categories = get_categories();
        $options = ['' => ''];
        foreach ( $categories as $cat ) {
            $options[$cat->term_id] = $cat->name;
        }
        return $options;
    }
}
Plugin::instance()->widgets_manager->register_widget_type( new Preferred_Magazine_Trading_Posts() );